@@ -44,16 +44,11 @@ class RequestError(PointError):
         self.__status_code = self.default_status_code if status_code is None else status_code
 
     def __str__(self):
-        return str(self.__detail)
+        return f'{self.__status_code}:{self.__url}:{self.__detail}'
 
-    def get_full_details(self):
-        if not status.is_client_error(self.__status_code):
-            raise PointError('Full details only for client errors')
-        return {
-            'detail': self.__detail,
-            'url': self.__url,
-            'status_code': self.__status_code
-        }
+    @property
+    def detail(self):
+        return self.__detail
 
 
 class ServerError(RequestError):
@@ -62,12 +57,12 @@ class ServerError(RequestError):
 
 class ClientError(RequestError):
     default_status_code = status.HTTP_400_BAD_REQUEST
-    default_detail = {'Invalid payload.'}
+    default_detail = 'Invalid payload.'
 
 
 class NotFound404(ClientError):
     default_status_code = status.HTTP_404_NOT_FOUND
-    default_detail = {'Not found'}
+    default_detail = 'Not found'
 
 
 class LookupFieldValueNone(PointError):
@@ -78,10 +73,6 @@ class SortByNotSet(PointError):
     pass
 
 
-class FilterAttrNotSet(PointError):
-    pass
-
-
 class ContractNotSet(PointError):
     pass
 
